@@ -11,6 +11,7 @@
 #' @param output [\code{character(1)}]\cr
 #'   Path to a file to write the output to. Defaults to \code{NULL} which means
 #'   that output is written to the active \code{\link[base]{sink}}.
+#'   Do not set this if your scheduler redirects output to a log file.
 #' @return [\code{character(1)}]: Hash of the \code{\link{JobCollection}} executed.
 #' @family JobCollection
 #' @export
@@ -27,7 +28,7 @@ doJobCollection = function(jc, output = NULL) {
 #' @export
 doJobCollection.character = function(jc, output = NULL) {
   obj = readRDS(jc)
-  if (!batchtools$debug)
+  if (!batchtools$debug && !obj$array.jobs)
     file.remove(jc)
   doJobCollection.JobCollection(obj, output = output)
 }
@@ -38,10 +39,11 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
   now = function() strftime(Sys.time())
 
   error = function(msg, ...) {
-    updates = data.table(job.id = jc$jobs$job.id, started = ustamp(), done = ustamp(),
+    now = ustamp()
+    updates = data.table(job.id = jc$jobs$job.id, started = now, done = now,
       error = stri_trunc(stri_trim_both(sprintf(msg, ...)), 500L, " [truncated]"),
       memory = NA_real_, key = "job.id")
-    writeRDS(updates, file = file.path(jc$file.dir, "updates", sprintf("%s-0.rds", jc$job.hash)), wait = TRUE)
+    writeRDS(updates, file = file.path(jc$file.dir, "updates", sprintf("%s.rds", jc$job.hash)))
     invisible(NULL)
   }
 
@@ -54,7 +56,8 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
 
   # setup output connection
   if (!is.null(output)) {
-    assertPathForOutput(output)
+    if (!testPathForOutput(output, overwrite = TRUE))
+      return(error("Cannot create output file for logging"))
     fp = file(output, open = "wt")
     sink(file = fp)
     sink(file = fp, type = "message")
@@ -62,19 +65,17 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
   }
 
   # subset array jobs
-  if (isTRUE(jc$resources$chunks.as.arrayjobs) && !is.na(jc$array.var)) {
-    i = Sys.getenv(jc$array.var)
-    if (nzchar(i)) {
-      i = as.integer(i)
-      if (!testInteger(i, any.missing = FALSE, lower = 1L, upper = nrow(jc$jobs)))
-        return(error("Failed to subset JobCollection using array environment variable '%s' [='%s']", jc$array.var, i))
-      jc$jobs = jc$jobs[i]
-    }
+  if (jc$array.jobs) {
+    i = as.integer(Sys.getenv(jc$array.var))
+    if (!testInteger(i, any.missing = FALSE, lower = 1L, upper = nrow(jc$jobs)))
+      return(error("Failed to subset JobCollection using array environment variable '%s' [='%s']", jc$array.var, i))
+    jc$jobs = jc$jobs[i]
   }
 
   # say hi
   n.jobs = nrow(jc$jobs)
   s = now()
+  catf("### [bt %s]: This is batchtools v%s", s, packageVersion("batchtools"))
   catf("### [bt %s]: Starting calculation of %i jobs", s, n.jobs)
   catf("### [bt %s]: Setting working directory to '%s'", s, jc$work.dir)
 
@@ -113,11 +114,11 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
   runHook(jc, "pre.do.collection", cache = cache)
 
   for (i in seq_len(n.jobs)) {
-    job = getJob(jc, jc$jobs[i], cache = cache)
+    job = getJob(jc, i, cache = cache)
     id = job$id
 
-    catf("### [bt %s]: Starting job [batchtools job.id=%i]", now(), id)
     update = list(started = ustamp(), done = NA_integer_, error = NA_character_, memory = NA_real_)
+    catf("### [bt %s]: Starting job [batchtools job.id=%i]", now(), id)
     if (measure.memory) {
       gc(reset = TRUE)
       result = try(execJob(job))
@@ -132,16 +133,16 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
       update$error = stri_trunc(stri_trim_both(as.character(result)), 500L, " [truncated]")
     } else {
       catf("\n### [bt %s]: Job terminated successfully [batchtools job.id=%i]", now(), id)
-      writeRDS(result, file = file.path(jc$file.dir, "results", sprintf("%i.rds", id)))
+      writeRDS(result, file = getResultFiles(jc, id))
     }
-    buf$add(id, update)
+    buf$add(i, update)
     buf$flush(jc)
   }
 
+  runHook(jc, "post.do.collection", updates = buf$updates, cache = cache)
   buf$save(jc)
-
   catf("### [bt %s]: Calculation finished!", now())
-  runHook(jc, "post.do.collection", cache = cache)
+
   invisible(jc$job.hash)
 }
 
@@ -150,30 +151,30 @@ UpdateBuffer = R6Class("UpdateBuffer",
   cloneable = FALSE,
   public = list(
     updates = NULL,
-    next.update = NA_integer_,
-    count = 0L,
+    next.update = NA_real_,
     initialize = function(ids) {
-      self$updates = data.table(job.id = ids, started = NA_integer_, done = NA_integer_, error = NA_character_, memory = NA_real_, written = FALSE, key = "job.id")
-      self$next.update = ustamp() + as.integer(runif(1L, 300, 1800))
+      self$updates = data.table(job.id = ids, started = NA_real_, done = NA_real_, error = NA_character_, memory = NA_real_, written = FALSE, key = "job.id")
+      self$next.update = Sys.time() + runif(1L, 300, 1800)
     },
 
-    add = function(id, x) {
-      self$updates[list(id), names(x) := x]
+    add = function(i, x) {
+      set(self$updates, i, names(x), x)
     },
 
     save = function(jc) {
-      i = self$updates[!written & !is.na(started), which = TRUE]
+      i = self$updates[!is.na(started) & (!written), which = TRUE]
       if (length(i) > 0L) {
-        self$count = self$count + 1L
-        writeRDS(self$updates[i, !"written", with = FALSE], file = file.path(jc$file.dir, "updates", sprintf("%s-%i.rds", jc$job.hash, self$count)), wait = TRUE)
-        self$updates[i, "written" := TRUE]
+        first.id = self$updates$job.id[i[1L]]
+        writeRDS(self$updates[i], file = file.path(jc$file.dir, "updates", sprintf("%s-%i.rds", jc$job.hash, first.id)))
+        set(self$updates, i, "written", TRUE)
       }
     },
 
     flush = function(jc) {
-      if (ustamp() > self$next.update) {
+      now = Sys.time()
+      if (now > self$next.update) {
         self$save(jc)
-        self$next.update = ustamp() + as.integer(runif(1L, 300, 1800))
+        self$next.update = now + runif(1L, 300, 1800)
       }
     }
 
