@@ -28,7 +28,10 @@ castIds = function(ids, setkey = TRUE) {
   if (is.data.frame(ids)) {
     "!DEBUG [castIds]: Casting ids from data.frame to data.table"
     ids$job.id = asInteger(ids$job.id, .var.name = "column 'job.id'")
-    return(as.data.table(ids, key = if (setkey) "job.id" else NULL))
+    ids = as.data.table(ids)
+    if (setkey)
+      setkeyv(ids, "job.id")
+    return(ids)
   }
 
   if (qtest(ids, "X")) {
@@ -36,7 +39,7 @@ castIds = function(ids, setkey = TRUE) {
     return(data.table(job.id = as.integer(ids), key = if (setkey) "job.id" else NULL))
   }
 
-  stop("Format of 'ids' not recognized. Must be a data frame with column 'job.id' or an integerish vector")
+  stop("Format of 'ids' not recognized. Must be a data.frame with column 'job.id' or an integerish vector")
 }
 
 convertIds = function(reg, ids, default = NULL, keep.extra = character(0L), keep.order = FALSE) {
@@ -47,18 +50,20 @@ convertIds = function(reg, ids, default = NULL, keep.extra = character(0L), keep
   if (anyDuplicated(ids, by = "job.id"))
     stop("Duplicated ids provided")
 
-  if (length(keep.extra) > 0L && ncol(ids) > 1L) {
-    sort = !keep.order || identical(key(ids), "job.id")
-    keep.extra = chintersect(keep.extra, names(ids))
-    return(merge(ids, reg$status, all = FALSE, sort = sort, by = "job.id")[, union("job.id", keep.extra), with = FALSE])
+  invalid = ids[!reg$status, on = "job.id", which = TRUE]
+  if (length(invalid) > 0L) {
+    info("Ignoring %i invalid job id", length(invalid), if (length(ids) > 1L) "s" else "")
+    ids = ids[-invalid]
   }
-  return(reg$status[ids, "job.id", on = "job.id", nomatch = 0L])
+
+  cols = if (length(keep.extra)) union("job.id", chintersect(keep.extra, names(ids))) else "job.id"
+  ids[, cols, with = FALSE]
 }
 
 convertId = function(reg, id) {
   id = convertIds(reg, id)
   if (nrow(id) != 1L)
-    stopf("You must provide exactly one id (%i provided)", nrow(id))
+    stopf("You must provide exactly one valid id (%i provided)", nrow(id))
   return(id)
 }
 
