@@ -156,7 +156,7 @@ submitJobs = function(ids = NULL, resources = list(), sleep = default.sleep, reg
   # handle max.concurrent.jobs
   max.concurrent.jobs = NA_integer_
   if (hasName(reg, "max.concurrent.jobs")) {
-    assertInt(reg$max.concurrent.jobs, lower = 0L)
+    assertCount(reg$max.concurrent.jobs)
     if (uniqueN(on.sys, by = "batch.id") + length(chunks) > reg$max.concurrent.jobs) {
       "!DEBUG [submitJobs]: Limiting the number of concurrent jobs to `reg$max.concurrent.jobs`"
       max.concurrent.jobs = reg$max.concurrent.jobs
